/*
Demo of the simplest on/off button code for Tiny44. 
This is adjusted code based on the example code of Robert Hart: http://fab.cba.mit.edu/classes/863.15/doc/tutorials/programming/Simple_examples/c_prog_examples.html. 

This code works by directly manipulating the register bits

In my case: 
Switch connected to PA3 (physical pin 10 of tiny44)
Yellow LED connected to PA7 (physical pin 6 of tiny44)
   
For details on the use of the registers PORtx, DDRx, and PINx  (where x = A or B) see tutorials on AVR programming.

This program was written by Robert Hart as a simple demonstration of programming AVR microcontrollers. 
*/

// ------- Preamble -------- //
/*This is a library that needs to be called upon for MAKE to know what to make of the code*/

#include <avr/io.h>                       

/* int main is a special function. It is added to all C code. All other functions are wrapped inside this function*/
int main(void) {                            
  // -------- Inits --------- //

/* initialize pullup resistor on our input pin (switch) by setting the bit of PA3 of register PORTA high. Check page 66 of the ATtiny datasheet for the register description.*/	
  PORTA = 0b00001000;  		
 /* Here we declare the LED pin PA7 as output pin by setting the DDA7 bit in the DDRA register to high.  (datatsheet p.66) */			
  DDRA = 0b10000000;                       

  // ------ Event loop ------ //
  /*while (1) declares a loop because 1 is always true.*/
  while (1) {
/* look for button press */   	 										
     if ((PINA & 0b00001000) == 0 ) { 		/* test to see if bit 3 of PINA is low  */
	  PORTA = 0b10001000;                   /* turn on LED on pin 7 of port A if bit is low (button is pressed) */
    }
    else {                                  /* otherwise */
      PORTA = 0b00001000;					/* leave output low.	*/
    }
   }										
    
                                        	 /* End event loop */
  return (0);	
 }

